@@ -147,10 +147,26 @@ class AlpacaBroker(with_metaclass(MetaAlpacaBroker, BrokerBase)):
         return cash
 
     def getvalue(self, datas=None):
-        # don't use self.o.get_value(). it takes time for local store to get
-        # update from broker.
-        self.value = float(self.o.oapi.get_account().portfolio_value)
-        return self.value
+        """
+        if datas then we will calculate the value of the positions if not
+        then the value of the entire portfolio (positions + cash)
+        :param datas: list of data objects
+        :return: float
+        """
+        if not datas:
+            # don't use self.o.get_value(). it takes time for local store to
+            # get update from broker.
+            self.value = float(self.o.oapi.get_account().portfolio_value)
+            return self.value
+        else:
+            # let's calculate the value of the positions
+            total_value = 0
+            for d in datas:
+                pos = self.getposition(d)
+                if pos.size:
+                    price = list(d)[0]
+                    total_value += price * pos.size
+            return total_value
 
     def getposition(self, data, clone=True):
         pos = self.positions[data]
@@ -226,30 +242,6 @@ class AlpacaBroker(with_metaclass(MetaAlpacaBroker, BrokerBase)):
 
     def _fill(self, oref, size, price, ttype, **kwargs):
         order = self.orders[oref]
-
-        if not order.alive():  # can be a bracket
-            pref = getattr(order.parent, 'ref', order.ref)
-            if pref not in self.brackets:
-                msg = ('Order fill received for {}, with price {} and size {} '
-                       'but order is no longer alive and is not a bracket. '
-                       'Unknown situation')
-                msg.format(order.ref, price, size)
-                self.put_notification(msg, order, price, size)
-                return
-
-            # [main, stopside, takeside], neg idx to array are -3, -2, -1
-            if ttype == 'STOP_LOSS_FILLED':
-                order = self.brackets[pref][-2]
-            elif ttype == 'TAKE_PROFIT_FILLED':
-                order = self.brackets[pref][-1]
-            else:
-                msg = ('Order fill received for {}, with price {} and size {} '
-                       'but order is no longer alive and is a bracket. '
-                       'Unknown situation')
-                msg.format(order.ref, price, size)
-                self.put_notification(msg, order, price, size)
-                return
-
         data = order.data
         pos = self.getposition(data, clone=False)
         psize, pprice, opened, closed = pos.update(size, price)
